PhoneField class
PhoneField entry point
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- manager → CountryManager
-
Get the country manager instance
no setter
Static Methods
-
initialize(
{CountryDataSource? remoteSource, List< Country> overrides = const []}) → Future<void> - Initialize the phone field plugin