CompositeValidator class

Composite validator (supports multiple validation strategies)

Implemented types

Constructors

CompositeValidator(List<PhoneValidator> validators)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validators List<PhoneValidator>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String phoneNumber, Country country) ValidationResult
override

Operators

operator ==(Object other) bool
The equality operator.
inherited