RegexValidator class

Regex-based validator (for future use)

Implemented types

Constructors

RegexValidator(Map<String, RegExp> countryPatterns)

Properties

countryPatterns Map<String, RegExp>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String phoneNumber, Country country) ValidationResult
override

Operators

operator ==(Object other) bool
The equality operator.
inherited