CustomPhoneField class

Custom phone input field with country selection

Inheritance

Constructors

CustomPhoneField({Key? key, PhoneFieldConfig config = const PhoneFieldConfig(), ValueChanged<PhoneNumber>? onChanged, FormFieldValidator<String>? validator, TextEditingController? controller, FocusNode? focusNode, ValueChanged<Country>? onCountryChanged, ValueChanged<String>? onSubmit, String? initialDialCode, String? initialCountryCode})
const

Properties

config PhoneFieldConfig
Configuration
final
controller TextEditingController?
Controller for the text field
final
focusNode FocusNode?
Focus node
final
hashCode int
The hash code for this object.
no setterinherited
initialCountryCode String?
Initial country code (e.g., 'IN', 'US')
final
initialDialCode String?
Initial country dial code (e.g., '+91', '91', '+1')
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ValueChanged<PhoneNumber>?
Called when phone number changes
final
onCountryChanged ValueChanged<Country>?
On country changed
final
onSubmit ValueChanged<String>?
On submit
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validator FormFieldValidator<String>?
Custom validator
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CustomPhoneField>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited