PhoneNumber class

Phone number data model

Constructors

PhoneNumber({required Country country, required String phoneNumber})

Properties

completeNumber String
Get complete phone number with country code
no setter
country Country
final
hashCode int
The hash code for this object.
no setterinherited
number String
Get phone number without country code
no setter
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited