CountryCache class
Cache for country data using SharedPreferences
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCache(
) → Future< void> - Clear the cache
-
isCacheValid(
) → Future< bool> - Check if cache is valid
-
loadCountries(
) → Future< Map< String, Country> ?> - Load countries from cache
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveCountries(
Map< String, Country> countries) → Future<void> - Save countries to cache
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited